@@ -1,10 +1,11 @@
 from .from_opx import from_opx
 from .to_svg import to_svg
 
-def opx2svg(infile, outfile, margin=10):
+
+def opx2svg(infile: str, outfile: str, margin=10):
     cp = from_opx(infile)
 
-    svgString = to_svg(cp, margin)
-    
+    svg_string = to_svg(cp, margin)
+
     with open(outfile, 'w') as im:
-        im.write(svgString)
+        im.write(svg_string)
